#
# spec file for package cups-pk-helper
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cups-pk-helper
Version:        0.2.7
Release:        1.8
Summary:        PolicyKit helper to configure cups with fine-grained privileges
License:        GPL-2.0-or-later
Group:          Hardware/Printing
URL:            https://www.freedesktop.org/wiki/Software/cups-pk-helper/
Source0:        https://www.freedesktop.org/software/cups-pk-helper/releases/%{name}-%{version}.tar.xz
BuildRequires:  cups-devel
BuildRequires:  meson
# For directory ownership
BuildRequires:  dbus-1
BuildRequires:  glib2-devel
BuildRequires:  polkit-devel
# Without cups installed, the cups-pk-helper-mechanism gives error: CRITICAL **: Failed to connect to cupsd
Requires:       cups >= 1.6

%description
This package provides a PolicyKit helper to configure cups with
fine-grained privileges. For example, it's possible to let users
enable/disable printers without requiring a password, while still
requiring a password for editing printer settings.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%files
%license COPYING
%doc AUTHORS NEWS README
%{_datadir}/dbus-1/system.d/org.opensuse.CupsPkHelper.Mechanism.conf
%{_libexecdir}/cups-pk-helper-mechanism
%{_datadir}/dbus-1/system-services/org.opensuse.CupsPkHelper.Mechanism.service
%{_datadir}/locale/en/
%{_datadir}/polkit-1/actions/org.opensuse.cupspkhelper.mechanism.policy

%files lang -f %{name}.lang
# english locale should be in the main package
%exclude %{_datadir}/locale/en

%changelog
* Thu Aug  4 2022 gmbr3@opensuse.org
- Update to version 0.2.7:
  + Use meson build system.
  + Remove code using CUPS 1.5 and lower.
  + Remove calls to deprecated g_type_init().
  + Move D-Bus conf file to $(datadir)/dbus-1/system.d
    (bsc#1202338).
  + Don't compare signed and unsigned int.
  + Add default statements to silence compiler warnings.
  + Add Code of Conduct.
  + Updated translations.
- Add meson BuildRequires and replace configure/make/make_install
  macros with relevant meson/meson_build/meson_install ones.
* Fri Jan 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend cups-pk-helper-lang: the lang package has
  relevant supplements which pulls it in whenever needed.
- Move /usr/share/locale/en from the -lang package to the main
  package: English is installed on all systems. This avoids
  cups-pk-helper-lang being triggered for installation on
  english-only systems.
- Modernize spec.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Feb 18 2016 dimstar@opensuse.org
- Update to version 0.2.6:
  + Enable UTF-8 chars in names and texts (bsc#1033742, rh#982727).
  + Introduce CPH_PATH_MAX.
  + Add function for printer renaming.
  + Updated translations.
* Sun Jun 16 2013 zaitor@opensuse.org
- Update to version 0.2.5:
  + Revert "Be stricter when validating printer names".
  + Updated translations.
* Wed Nov 28 2012 dimstar@opensuse.org
- Add cups requires: Without cups being installed, cups-pk-helper
  can't do any of its tasks (bnc#783865).
* Sat Oct 13 2012 zaitor@opensuse.org
- Update to version 0.2.4:
  + Fix detection of CUPS version.
* Fri Oct 12 2012 vuntz@opensuse.org
- Update to version 0.2.3:
  + Fix security flaw in cupsGetFile/cupsPutFile wrappers
    (CVE-2012-4510, bnc#783488)
  + Escape printer/class names before putting them in URIs
  + Be stricter when validating printer names
  + Fix build with CUPS >= 1.6
  + New/updated translations.
* Fri Mar 16 2012 praful.johari@gmail.com
- Update to version 0.2.2:
  + Add PrinterAddOption D-Bus method.
  + Set requesting-user-name tag in requests.
  + Code cleanups.
  + Build fixes and improvements.
  + New/updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 0.2.1:
  + Do not pass ppd file if empty when adding a printer.
  + Accept NULL for ppd file as valid when adding a printer.
  + Allow inactive/any users to authenticate.
  + Updated translations.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 0.2.0:
  + Port to GDBus.
  + Stop using deprecated polkit API.
  + Drop gthread handling.
  + Add org.freedesktop.DBus.Deprecated annotation to JobCancel.
  + Code cleanups.
  + Build system improvements.
  + Updated translations.
- Remove dbus-1-glib-devel BuildRequires, now unneeded.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 0.1.3:
  + Allow file request with NULL filename, to add raw printers.
  + Modernize build system a bit.
  + Updated translations.
- Stop using a custom libexecdir, and keep the standard one.
* Fri Jun 17 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 0.1.2:
  + Add all-edit action to enable authenticating only once in tools
  + Build system improvements.
  + Updated translations.
- Use source services: download_url and set_version.
* Thu Jan 13 2011 vuntz@opensuse.org
- Update to version 0.1.1:
  + Make the include/exclude schemes work when getting devices with
    cups 1.4
  + Fix confusion between IPP and HTTP status when getting/putting
    a file
  + Clarify a string.
  + Add some basic documentation.
  + Build system improvements.
  + First translations.
- Drop cups-pk-helper-buildfix.patch: fixed upstream.
- Create a lang subpackage, that is recommended by the main
  package.
* Mon Mar 22 2010 dimstar@opensuse.org
- Add cups-pk-helper-buildfix.patch to fix build, taken from
  upstream.
* Tue Feb 16 2010 vuntz@opensuse.org
- Update to version 0.1.0:
  + Port to PolicyKit 1.
  + Add DevicesGet method.
  + Add JobCancelPurge method.
  + Support adding printer without device URI.
  + Add check for string length in validity checks.
  + Improve performance of job-related methods.
  + Make sure to correctly handle all CUPS replies.
  + Avoid timeout on job-related methods for invalid jobs.
  + Always return a non-empty error string in case of failures.
  + Remove GTK+/GIO requirements.
  + Minor fixes and improvements in tests.
  + Code cleanups.
  + Build system improvements.
- Change PolicyKit-devel BuildRequires to polkit-devel.
- Add glib2-devel BuildRequires.
- Remove gtk2-devel BuildRequires.
* Wed Mar  4 2009 vuntz@novell.com
- Update to version 0.0.4:
  + Remove bare send_interface lines in the DBus rules.
  + Add job related functions.
  + Reconnect to the cups server if necessary.
  + Accept file: URI as local.
  + Change default policy for job-edit to yes (jobs are owned by
    the user).
  + Add more checks for the new job-related functions.
  + Code cleanups.
- Drop cups-pk-helper-bnc468389-dbus-send-dest.patch: fixed
  upstream.
* Sat Feb 21 2009 vuntz@novell.com
- Split from system-config-printer.
